"use strict";

var _directoryTree = _interopRequireDefault(require("directory-tree"));

var _fs = require("fs");

var _path = require("path");

var _spawnCommand = _interopRequireDefault(require("spawn-command"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const EXAMPLE_DIR = 'examples/coverage';

const getInputFile = (dir = EXAMPLE_DIR) => (0, _directoryTree.default)(dir, {
  extensions: /\.(json)/
});

const getOutputFile = (dir = EXAMPLE_DIR) => (0, _directoryTree.default)(dir, {
  extensions: /\.csv/
});

const clearOutputs = (dir = EXAMPLE_DIR) => {
  const outputFile = getOutputFile(dir);
  outputFile.children.forEach(img => {
    (0, _fs.unlinkSync)(img.path);
  });
};

const runCLI = (args = '', cwd = process.cwd()) => {
  const isRelative = cwd[0] !== '/';
  let workingDir = cwd;

  if (isRelative) {
    workingDir = (0, _path.resolve)(__dirname, cwd);
  }

  return new Promise((resolve, reject) => {
    let stdout = '';
    let stderr = '';
    const command = `yarn start ${args}`;
    const child = (0, _spawnCommand.default)(command, {
      cwd: workingDir
    });
    child.on('error', error => {
      reject(error);
    });
    child.stdout.on('data', data => {
      stdout += data.toString();
    });
    child.stderr.on('data', data => {
      stderr += data.toString();
    });
    child.on('close', () => {
      if (stderr) {
        reject(stderr);
      } else {
        resolve(stdout);
      }
    });
  });
};

describe('Blackbox Test', () => {
  test('jest-coverage-to-csv --help', () => runCLI('--help').then(stdout => {
    expect(stdout).toMatchSnapshot();
  }));
  describe('Convert Coverage to CSV', () => {
    beforeEach(() => {
      clearOutputs();
    });
    afterEach(() => {
      clearOutputs();
    });
    test('jest-coverage-to-csv examples/coverage/coverage-summary.json  examples/coverage/coverage-summary.csv | it converts the json file', async () => {
      const inputFile = getInputFile();
      let outputFile = getOutputFile();
      expect(inputFile.children.length).toBe(1);
      expect(outputFile.children.length).toBe(0);
      return runCLI(`${EXAMPLE_DIR}/coverage-summary.json ${EXAMPLE_DIR}/coverage-summary.csv`).then(stdout => {
        outputFile = getOutputFile();
        expect(outputFile.children.length).toBe(1);
        expect(stdout.match(/Conversion to CSV success!/g)).toHaveLength(1);
        const fileContent = (0, _fs.readFileSync)(`${EXAMPLE_DIR}/coverage-summary.csv`, {
          encoding: 'utf8'
        });
        expect(fileContent).toMatchSnapshot();
      });
    });
    test('jest-coverage-to-csv examples/coverage/coverage-summary.json  examples/coverage/coverage-summary.csv --so --po | it converts the json file with option --so --po', async () => {
      const inputFile = getInputFile();
      let outputFile = getOutputFile();
      expect(inputFile.children.length).toBe(1);
      expect(outputFile.children.length).toBe(0);
      return runCLI(`${EXAMPLE_DIR}/coverage-summary.json ${EXAMPLE_DIR}/coverage-summary.csv --so --po`).then(stdout => {
        outputFile = getOutputFile();
        expect(outputFile.children.length).toBe(1);
        expect(stdout.match(/Conversion to CSV success!/g)).toHaveLength(1);
        const fileContent = (0, _fs.readFileSync)(`${EXAMPLE_DIR}/coverage-summary.csv`, {
          encoding: 'utf8'
        });
        expect(fileContent).toMatchSnapshot();
      });
    });
  });
});